@@ -6,5 +6,7 @@ cd ../barbell2/createh5
 python createh5.py \
     /Volumes/USB_SECURE1/data/radiomics/projects/deepseg/data/mega/final \
     ${HOME}/Desktop/h5 \
-    --split="HEERLEN, NEWEPOC" \
+    --output_file_name_training=training.h5 \
+    --output_file_name_validation=validation.h5 \
+    --split="FROGS, HEERLEN, MAASTRICHT_AKEN, NEWEPOC" \
     --split_percentage=0.8
